@@ -5,10 +5,10 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="64"/>
-        <location filename="../mainwindow.cpp" line="434"/>
+        <location filename="../mainwindow.cpp" line="68"/>
+        <location filename="../mainwindow.cpp" line="289"/>
         <source>MX Welcome</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Приветствие</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="80"/>
@@ -43,62 +43,62 @@
     <message>
         <location filename="../mainwindow.ui" line="203"/>
         <source>Welcome</source>
-        <translation type="unfinished"></translation>
+        <translation>Добро пожаловать</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="484"/>
         <source>Install MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Установить MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="510"/>
         <source>Tweak (Panel, etc...)</source>
-        <translation type="unfinished"></translation>
+        <translation>Настройка (панели и пр.)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="536"/>
         <source>Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Инструменты</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="568"/>
         <source>Wiki</source>
-        <translation type="unfinished"></translation>
+        <translation>Вики</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="600"/>
         <source>Users Manual</source>
-        <translation type="unfinished"></translation>
+        <translation>Руководство пользователя</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="626"/>
         <source>FAQ</source>
-        <translation type="unfinished"></translation>
+        <translation>ЧаВо</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="652"/>
         <source>Tour</source>
-        <translation type="unfinished"></translation>
+        <translation>Обзор</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="674"/>
         <source>Popular Apps</source>
-        <translation type="unfinished"></translation>
+        <translation>Популярные приложения</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="700"/>
         <source>Contribute</source>
-        <translation type="unfinished"></translation>
+        <translation>Поддержать</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="732"/>
         <source>Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Видео</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="764"/>
         <source>Forums</source>
-        <translation type="unfinished"></translation>
+        <translation>Форумы</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="790"/>
@@ -120,91 +120,91 @@ li.checked::marker { content: &quot;\2612&quot;; }
     <message>
         <location filename="../mainwindow.ui" line="923"/>
         <source>SHORT SYSTEM REPORT:</source>
-        <translation type="unfinished"></translation>
+        <translation>КРАТКИЙ ОТЧЁТ О СИСТЕМЕ:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="798"/>
         <source>DESKTOP</source>
-        <translation type="unfinished"></translation>
+        <translation>РАБОЧИЙ СТОЛ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="815"/>
         <source>Quick-System-Info Full Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Подробный отчёт Quick-System-Info</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="825"/>
         <source>Terms of Use</source>
-        <translation type="unfinished"></translation>
+        <translation>Условия использования</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="845"/>
         <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
-        <translation type="unfinished"></translation>
+        <translation>Название «MX Linux» подпадает под сублицензию Linux Foundation No. 20140605-0483. Мы разрабатываем программное обеспечение, на которое распространяется бесплатная лицензия, доступная в списке Вики. Мы также включаем программное обеспечение, разработанное другими, которое также имеет бесплатную лицензию.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="855"/>
         <source>MX VERSION</source>
-        <translation type="unfinished"></translation>
+        <translation>ВЕРСИЯ MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="862"/>
         <source>DEBIAN VERSION:</source>
-        <translation type="unfinished"></translation>
+        <translation>ВЕРСИЯ DEBIAN:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="869"/>
         <source>SUPPORTED UNTIL:</source>
-        <translation type="unfinished"></translation>
+        <translation>СРОК ПОДДЕРЖКИ:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="939"/>
         <source>Show this dialog at start up</source>
-        <translation type="unfinished"></translation>
+        <translation>Показывать этот диалог при запуске</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="317"/>
+        <location filename="../mainwindow.cpp" line="176"/>
         <source>User demo, password:</source>
-        <translation type="unfinished"></translation>
+        <translation>Пароль пользователя demo:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="318"/>
+        <location filename="../mainwindow.cpp" line="177"/>
         <source>Superuser root, password:</source>
-        <translation type="unfinished"></translation>
+        <translation>Пароль суперпользователя root:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="355"/>
-        <location filename="../mainwindow.cpp" line="373"/>
+        <location filename="../mainwindow.cpp" line="205"/>
+        <location filename="../mainwindow.cpp" line="223"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="386"/>
+        <location filename="../mainwindow.cpp" line="238"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="433"/>
+        <location filename="../mainwindow.cpp" line="288"/>
         <source>About MX Welcome</source>
-        <translation type="unfinished"></translation>
+        <translation>О программе MX Приветствие</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="434"/>
+        <location filename="../mainwindow.cpp" line="289"/>
         <source>Version: </source>
         <translation>Версия: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="435"/>
+        <location filename="../mainwindow.cpp" line="290"/>
         <source>Program for displaying a welcome screen in MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Программа показа экрана приветствия в MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="438"/>
+        <location filename="../mainwindow.cpp" line="293"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="439"/>
+        <location filename="../mainwindow.cpp" line="294"/>
         <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
@@ -225,51 +225,58 @@ li.checked::marker { content: &quot;\2612&quot;; }
         <translation type="vanished">&amp;Закрыть</translation>
     </message>
 </context>
+<context>
+    <name>QApplication</name>
+    <message>
+        <source>You must run this program as normal user.</source>
+        <translation type="vanished">Вы должны запустить эту программу как обычный пользователь.</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
         <location filename="../main.cpp" line="44"/>
         <source>This tool displays a welcome screen with two tabs.</source>
-        <translation type="unfinished"></translation>
+        <translation>Этот инструмент отображает экран приветствия с двумя вкладками.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="48"/>
         <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
-        <translation type="unfinished"></translation>
+        <translation>Начните с выбора вкладки «О системе». В ней представлены основная информация о текущей версии MX Linux и оборудовании пользователя, а также доступ к полному системному отчёту.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Run a test mode.</source>
-        <translation type="unfinished"></translation>
+        <translation>Запустить тестовый режим.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="76"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../main.cpp" line="76"/>
         <source>You must run this program as normal user.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вы должны запустить эту программу как обычный пользователь.</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="39"/>
+        <location filename="../about.cpp" line="61"/>
         <source>License</source>
         <translation type="unfinished">Лицензия</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="40"/>
-        <location filename="../about.cpp" line="50"/>
+        <location filename="../about.cpp" line="62"/>
+        <location filename="../about.cpp" line="72"/>
         <source>Changelog</source>
         <translation type="unfinished">Список изменений</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="41"/>
+        <location filename="../about.cpp" line="63"/>
         <source>Cancel</source>
         <translation type="unfinished">Отмена</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="63"/>
+        <location filename="../about.cpp" line="85"/>
         <source>&amp;Close</source>
         <translation type="unfinished">&amp;Закрыть</translation>
     </message>
